[longomatch] Rename PlayerBin to PlayerView
- From: Andoni Morales Alastruey <amorales src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [longomatch] Rename PlayerBin to PlayerView
- Date: Tue, 31 Mar 2015 17:31:03 +0000 (UTC)
commit dfdb1a2a876b8297e73f862225938404c4cd3002
Author: Andoni Morales Alastruey <ylatuya gmail com>
Date: Mon Mar 23 11:56:24 2015 +0100
Rename PlayerBin to PlayerView
.../Gui/{PlayerBin.cs => PlayerView.cs} | 4 ++--
.../LongoMatch.GUI.Multimedia.csproj | 4 ++--
.../gtk-gui/LongoMatch.Gui.PlayerCapturerBin.cs | 4 ++--
...i.PlayerBin.cs => LongoMatch.Gui.PlayerView.cs} | 16 ++++------------
LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic | 2 +-
LongoMatch.GUI.Multimedia/gtk-gui/objects.xml | 10 ++++------
.../LongoMatch.Gui.Component.ProjectPeriods.cs | 8 ++++----
7 files changed, 19 insertions(+), 29 deletions(-)
---
diff --git a/LongoMatch.GUI.Multimedia/Gui/PlayerBin.cs b/LongoMatch.GUI.Multimedia/Gui/PlayerView.cs
similarity index 99%
rename from LongoMatch.GUI.Multimedia/Gui/PlayerBin.cs
rename to LongoMatch.GUI.Multimedia/Gui/PlayerView.cs
index c6e4318..913eace 100644
--- a/LongoMatch.GUI.Multimedia/Gui/PlayerBin.cs
+++ b/LongoMatch.GUI.Multimedia/Gui/PlayerView.cs
@@ -40,7 +40,7 @@ namespace LongoMatch.Gui
[System.ComponentModel.Category ("LongoMatch")]
[System.ComponentModel.ToolboxItem (true)]
- public partial class PlayerBin : Gtk.Bin
+ public partial class PlayerView : Gtk.Bin
{
const int SCALE_FPS = 25;
IPlayerController player;
@@ -52,7 +52,7 @@ namespace LongoMatch.Gui
#region Constructors
- public PlayerBin ()
+ public PlayerView ()
{
this.Build ();
diff --git a/LongoMatch.GUI.Multimedia/LongoMatch.GUI.Multimedia.csproj
b/LongoMatch.GUI.Multimedia/LongoMatch.GUI.Multimedia.csproj
index 4b74ec7..6cb8e27 100644
--- a/LongoMatch.GUI.Multimedia/LongoMatch.GUI.Multimedia.csproj
+++ b/LongoMatch.GUI.Multimedia/LongoMatch.GUI.Multimedia.csproj
@@ -42,12 +42,10 @@
</ItemGroup>
<ItemGroup>
<Compile Include="Gui\CapturerBin.cs" />
- <Compile Include="Gui\PlayerBin.cs" />
<Compile Include="Gui\VolumeWindow.cs" />
<Compile Include="gtk-gui\generated.cs" />
<Compile Include="gtk-gui\LongoMatch.Gui.CapturerBin.cs" />
<Compile Include="gtk-gui\LongoMatch.Gui.VolumeWindow.cs" />
- <Compile Include="gtk-gui\LongoMatch.Gui.PlayerBin.cs" />
<Compile Include="Gui\PlayerCapturerBin.cs" />
<Compile Include="gtk-gui\LongoMatch.Gui.PlayerCapturerBin.cs" />
<Compile Include="Gui\Utils\Remuxer.cs" />
@@ -55,6 +53,8 @@
<Compile Include="Gui\Utils\FramesCapturer.cs" />
<Compile Include="Gui\VideoWindow.cs" />
<Compile Include="gtk-gui\LongoMatch.Gui.VideoWindow.cs" />
+ <Compile Include="Gui\PlayerView.cs" />
+ <Compile Include="gtk-gui\LongoMatch.Gui.PlayerView.cs" />
</ItemGroup>
<ItemGroup>
<EmbeddedResource Include="gtk-gui\gui.stetic">
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerCapturerBin.cs
b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerCapturerBin.cs
index b06150b..9fb3640 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerCapturerBin.cs
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerCapturerBin.cs
@@ -14,7 +14,7 @@ namespace LongoMatch.Gui
private global::Gtk.Label replaylabel;
- private global::LongoMatch.Gui.PlayerBin playerbin;
+ private global::LongoMatch.Gui.PlayerView playerbin;
private global::Gtk.VBox capturerbox;
@@ -68,7 +68,7 @@ namespace LongoMatch.Gui
w3.Expand = false;
w3.Fill = false;
// Container child playerbox.Gtk.Box+BoxChild
- this.playerbin = new global::LongoMatch.Gui.PlayerBin ();
+ this.playerbin = new global::LongoMatch.Gui.PlayerView ();
this.playerbin.Events = ((global::Gdk.EventMask)(256));
this.playerbin.Name = "playerbin";
this.playerbox.Add (this.playerbin);
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
index 54a0b42..c9b72b1 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
@@ -74,7 +74,7 @@
</widget>
</child>
</widget>
- <widget class="Gtk.Bin" id="LongoMatch.Gui.PlayerBin" design-size="1080 433">
+ <widget class="Gtk.Bin" id="LongoMatch.Gui.PlayerView" design-size="1080 433">
<property name="MemberName" />
<child>
<widget class="Gtk.VBox" id="vbox3">
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/objects.xml b/LongoMatch.GUI.Multimedia/gtk-gui/objects.xml
index 32c81e9..7441513 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/objects.xml
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/objects.xml
@@ -7,12 +7,6 @@
</itemgroups>
<signals />
</object>
- <object type="LongoMatch.Gui.PlayerBin" palette-category="General" allow-children="false"
base-type="Gtk.Bin">
- <itemgroups>
- </itemgroups>
- <signals>
- </signals>
- </object>
<object type="LongoMatch.Gui.PlayerCapturerBin" palette-category="General" allow-children="false"
base-type="Gtk.Bin">
<itemgroups>
</itemgroups>
@@ -34,4 +28,8 @@
</itemgroup>
</signals>
</object>
+ <object type="LongoMatch.Gui.PlayerView" palette-category="LongoMatch" allow-children="false"
base-type="Gtk.Bin">
+ <itemgroups />
+ <signals />
+ </object>
</objects>
\ No newline at end of file
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.ProjectPeriods.cs
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.ProjectPeriods.cs
index 7ce9558..3e2188d 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.ProjectPeriods.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.ProjectPeriods.cs
@@ -12,7 +12,7 @@ namespace LongoMatch.Gui.Component
private global::Gtk.VBox main_cam_vbox;
- private global::LongoMatch.Gui.PlayerBin main_cam_playerbin;
+ private global::LongoMatch.Gui.PlayerView main_cam_playerbin;
private global::Gtk.HBox main_cam_hbox;
@@ -26,7 +26,7 @@ namespace LongoMatch.Gui.Component
private global::Gtk.VBox sec_cam_vbox;
- private global::LongoMatch.Gui.PlayerBin sec_cam_playerbin;
+ private global::LongoMatch.Gui.PlayerView sec_cam_playerbin;
private global::Gtk.HBox sec_cam_hbox;
@@ -89,7 +89,7 @@ namespace LongoMatch.Gui.Component
this.main_cam_vbox.Name = "main_cam_vbox";
this.main_cam_vbox.Spacing = 6;
// Container child main_cam_vbox.Gtk.Box+BoxChild
- this.main_cam_playerbin = new global::LongoMatch.Gui.PlayerBin ();
+ this.main_cam_playerbin = new global::LongoMatch.Gui.PlayerView ();
this.main_cam_playerbin.Events = ((global::Gdk.EventMask)(256));
this.main_cam_playerbin.Name = "main_cam_playerbin";
this.main_cam_vbox.Add (this.main_cam_playerbin);
@@ -138,7 +138,7 @@ namespace LongoMatch.Gui.Component
this.sec_cam_vbox.Name = "sec_cam_vbox";
this.sec_cam_vbox.Spacing = 6;
// Container child sec_cam_vbox.Gtk.Box+BoxChild
- this.sec_cam_playerbin = new global::LongoMatch.Gui.PlayerBin ();
+ this.sec_cam_playerbin = new global::LongoMatch.Gui.PlayerView ();
this.sec_cam_playerbin.Events = ((global::Gdk.EventMask)(256));
this.sec_cam_playerbin.Name = "sec_cam_playerbin";
this.sec_cam_vbox.Add (this.sec_cam_playerbin);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerView.cs
similarity index 96%
rename from LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
rename to LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerView.cs
index 8ce794a..d131402 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerView.cs
@@ -2,7 +2,7 @@
// This file has been generated by the GUI designer. Do not modify.
namespace LongoMatch.Gui
{
- public partial class PlayerBin
+ public partial class PlayerView
{
private global::Gtk.VBox vbox3;
@@ -75,10 +75,10 @@ namespace LongoMatch.Gui
protected virtual void Build ()
{
global::Stetic.Gui.Initialize (this);
- // Widget LongoMatch.Gui.PlayerBin
+ // Widget LongoMatch.Gui.PlayerView
global::Stetic.BinContainer.Attach (this);
- this.Name = "LongoMatch.Gui.PlayerBin";
- // Container child LongoMatch.Gui.PlayerBin.Gtk.Container+ContainerChild
+ this.Name = "LongoMatch.Gui.PlayerView";
+ // Container child LongoMatch.Gui.PlayerView.Gtk.Container+ContainerChild
this.vbox3 = new global::Gtk.VBox ();
this.vbox3.Name = "vbox3";
this.vbox3.Spacing = 6;
@@ -172,7 +172,6 @@ namespace LongoMatch.Gui
this.closebuttonimage = new global::Gtk.Image ();
this.closebuttonimage.Name = "closebuttonimage";
this.closebutton.Add (this.closebuttonimage);
- this.closebutton.Label = null;
this.buttonsbox.Add (this.closebutton);
global::Gtk.Box.BoxChild w10 = ((global::Gtk.Box.BoxChild)(this.buttonsbox
[this.closebutton]));
w10.Position = 0;
@@ -187,7 +186,6 @@ namespace LongoMatch.Gui
this.drawbuttonimage = new global::Gtk.Image ();
this.drawbuttonimage.Name = "drawbuttonimage";
this.drawbutton.Add (this.drawbuttonimage);
- this.drawbutton.Label = null;
this.buttonsbox.Add (this.drawbutton);
global::Gtk.Box.BoxChild w12 = ((global::Gtk.Box.BoxChild)(this.buttonsbox
[this.drawbutton]));
w12.Position = 1;
@@ -202,7 +200,6 @@ namespace LongoMatch.Gui
this.playbuttonimage = new global::Gtk.Image ();
this.playbuttonimage.Name = "playbuttonimage";
this.playbutton.Add (this.playbuttonimage);
- this.playbutton.Label = null;
this.buttonsbox.Add (this.playbutton);
global::Gtk.Box.BoxChild w14 = ((global::Gtk.Box.BoxChild)(this.buttonsbox
[this.playbutton]));
w14.Position = 2;
@@ -217,7 +214,6 @@ namespace LongoMatch.Gui
this.pausebuttonimage = new global::Gtk.Image ();
this.pausebuttonimage.Name = "pausebuttonimage";
this.pausebutton.Add (this.pausebuttonimage);
- this.pausebutton.Label = null;
this.buttonsbox.Add (this.pausebutton);
global::Gtk.Box.BoxChild w16 = ((global::Gtk.Box.BoxChild)(this.buttonsbox
[this.pausebutton]));
w16.Position = 3;
@@ -232,7 +228,6 @@ namespace LongoMatch.Gui
this.prevbuttonimage = new global::Gtk.Image ();
this.prevbuttonimage.Name = "prevbuttonimage";
this.prevbutton.Add (this.prevbuttonimage);
- this.prevbutton.Label = null;
this.buttonsbox.Add (this.prevbutton);
global::Gtk.Box.BoxChild w18 = ((global::Gtk.Box.BoxChild)(this.buttonsbox
[this.prevbutton]));
w18.Position = 4;
@@ -248,7 +243,6 @@ namespace LongoMatch.Gui
this.nextbuttonimage = new global::Gtk.Image ();
this.nextbuttonimage.Name = "nextbuttonimage";
this.nextbutton.Add (this.nextbuttonimage);
- this.nextbutton.Label = null;
this.buttonsbox.Add (this.nextbutton);
global::Gtk.Box.BoxChild w20 = ((global::Gtk.Box.BoxChild)(this.buttonsbox
[this.nextbutton]));
w20.Position = 5;
@@ -327,7 +321,6 @@ namespace LongoMatch.Gui
this.volumebuttonimage = new global::Gtk.Image ();
this.volumebuttonimage.Name = "volumebuttonimage";
this.volumebutton.Add (this.volumebuttonimage);
- this.volumebutton.Label = null;
this.controlsbox.Add (this.volumebutton);
global::Gtk.Box.BoxChild w29 = ((global::Gtk.Box.BoxChild)(this.controlsbox
[this.volumebutton]));
w29.Position = 5;
@@ -342,7 +335,6 @@ namespace LongoMatch.Gui
this.detachbuttonimage = new global::Gtk.Image ();
this.detachbuttonimage.Name = "detachbuttonimage";
this.detachbutton.Add (this.detachbuttonimage);
- this.detachbutton.Label = null;
this.controlsbox.Add (this.detachbutton);
global::Gtk.Box.BoxChild w31 = ((global::Gtk.Box.BoxChild)(this.controlsbox
[this.detachbutton]));
w31.Position = 6;